//@line 36 "/builds/moz2_slave/linux_repack/build/releases/l10n-mozilla-1.9.1/af/browser/firefox-l10n.js"

//@line 38 "/builds/moz2_slave/linux_repack/build/releases/l10n-mozilla-1.9.1/af/browser/firefox-l10n.js"

pref("general.useragent.locale", "af");
